@@ -193,14 +193,15 @@ class StrictRedis(object):
     """
     RESPONSE_CALLBACKS = dict_merge(
         string_keys_to_dict(
-            'AUTH DEL EXISTS EXPIRE EXPIREAT HDEL HEXISTS HMSET MOVE MSETNX '
-            'PERSIST PSETEX RENAMENX SISMEMBER SMOVE SETEX SETNX ZREM',
+            'AUTH EXISTS EXPIRE EXPIREAT HEXISTS HMSET MOVE MSETNX PERSIST '
+            'PSETEX RENAMENX SISMEMBER SMOVE SETEX SETNX',
             bool
         ),
         string_keys_to_dict(
-            'BITCOUNT DECRBY GETBIT HLEN INCRBY LINSERT LLEN LPUSHX RPUSHX '
-            'SADD SCARD SDIFFSTORE SETBIT SETRANGE SINTERSTORE SREM STRLEN '
-            'SUNIONSTORE ZADD ZCARD ZREMRANGEBYRANK ZREMRANGEBYSCORE',
+            'BITCOUNT DECRBY DEL GETBIT HDEL HLEN INCRBY LINSERT LLEN LPUSHX '
+            'RPUSHX SADD SCARD SDIFFSTORE SETBIT SETRANGE SINTERSTORE SREM '
+            'STRLEN SUNIONSTORE ZADD ZCARD ZREM ZREMRANGEBYRANK '
+            'ZREMRANGEBYSCORE',
             int
         ),
         string_keys_to_dict('INCRBYFLOAT HINCRBYFLOAT', float),
@@ -274,7 +275,7 @@ class StrictRedis(object):
             except (AttributeError, ValueError):
                 db = 0
 
-        return cls(host=url.hostname, port=url.port, db=db,
+        return cls(host=url.hostname, port=int(url.port or 6379), db=db,
                    password=url.password, **kwargs)
 
     def __init__(self, host='localhost', port=6379,
