@@ -9,7 +9,15 @@ class AuthenticationError(RedisError):
     pass
 
 
-class ConnectionError(RedisError):
+class ServerError(RedisError):
+    pass
+
+
+class ConnectionError(ServerError):
+    pass
+
+
+class InvalidResponse(ServerError):
     pass
 
 
@@ -17,10 +25,6 @@ class ResponseError(RedisError):
     pass
 
 
-class InvalidResponse(RedisError):
-    pass
-
-
 class DataError(RedisError):
     pass
 
@@ -32,5 +36,10 @@ class PubSubError(RedisError):
 class WatchError(RedisError):
     pass
 
+
 class NoScriptError(ResponseError):
     pass
+
+
+class ExecAbortError(ResponseError):
+    pass
